@@ -1,3 +1,5 @@
+import uuid
+
 from django.conf import settings
 from ..aws.sns_client_extended import SNSClientExtended
 from .event_base import EventBase
@@ -11,15 +13,17 @@ class EventBaseAws(EventBase):
     AWS_S3_QUEUE_STORAGE_NAME = settings.AWS_S3_QUEUE_STORAGE_NAME
     AWS_SNS_TOPIC = None
 
-    def dispatch(self, event_name, event_data, message_group_id: str = None):
+    def dispatch(self, event_name, event_data, message_group_id: str = None, message_deduplication_id: str = None):
         message_attributes = {'event_type': {'DataType': 'String', 'StringValue': event_name}}
         sns = SNSClientExtended(self.AWS_ACCESS_KEY_ID,
                                 self.AWS_SECRET_ACCESS_KEY,
                                 self.AWS_DEFAULT_REGION,
                                 self.AWS_S3_QUEUE_STORAGE_NAME)
         return sns.send_message(
-            self.AWS_SNS_TOPIC,
-            event_data,
+            topic=self.AWS_SNS_TOPIC,
+            message=event_data,
             message_attributes=message_attributes,
             message_group_id=message_group_id,
-        )
\ No newline at end of file
+            message_deduplication_id=message_deduplication_id
+        )
+
